This makes it clearer this code is part of the coredump code, and
is not an exported generic helper from kernel/umh.c.

Signed-off-by: Luis R. Rodriguez <mcg...@kernel.org>
---
 fs/coredump.c | 9 +++++----
 1 file changed, 5 insertions(+), 4 deletions(-)

diff --git a/fs/coredump.c b/fs/coredump.c
index 1e2c87acac9b..566504781683 100644
--- a/fs/coredump.c
+++ b/fs/coredump.c
@@ -508,7 +508,7 @@ static void wait_for_dump_helpers(struct file *file)
 }
 
 /*
- * umh_pipe_setup
+ * coredump_pipe_setup
  * helper function to customize the process used
  * to collect the core in userspace.  Specifically
  * it sets up a pipe and installs it as fd 0 (stdin)
@@ -518,7 +518,7 @@ static void wait_for_dump_helpers(struct file *file)
  * is a special value that we use to trap recursive
  * core dumps
  */
-static int umh_pipe_setup(struct subprocess_info *info, struct cred *new)
+static int coredump_pipe_setup(struct subprocess_info *info, struct cred *new)
 {
        struct file *files[2];
        struct coredump_params *cp = (struct coredump_params *)info->data;
@@ -606,7 +606,7 @@ void do_coredump(const siginfo_t *siginfo)
                }
 
                if (cprm.limit == 1) {
                        /* See umh_pipe_setup() which sets RLIMIT_CORE = 1.
                         *
                         * Normally core limits are irrelevant to pipes, since
                         * we're not writing to the file system, but we use
@@ -647,7 +647,8 @@ void do_coredump(const siginfo_t *siginfo)
                retval = -ENOMEM;
                sub_info = call_usermodehelper_setup(helper_argv[0],
                                                helper_argv, NULL, GFP_KERNEL,
-                                               umh_pipe_setup, NULL, &cprm);
+                                               coredump_pipe_setup, NULL,
+                                               &cprm);
                if (sub_info)
                        retval = call_usermodehelper_exec(sub_info,
                                                          UMH_WAIT_EXEC);
@@ -606,7 +606,7 @@ void do_coredump(const siginfo_t *siginfo)
 
                if (cprm.limit == 1) {
-                       /* See umh_pipe_setup() which sets RLIMIT_CORE = 1.
+                       /* See coredump_pipe_setup() which sets RLIMIT_CORE = 1.
                         *
                         * Normally core limits are irrelevant to pipes, since
-- 
2.17.0

Reply via email to